@@ -1,3 +1,4 @@
+import inspect
 import logging
 from enum import Enum
 from typing import Any, Optional  # noqa: F401
@@ -20,12 +21,13 @@ class UpdateState(Enum):
 
 class DeviceInfo:
     """Container of miIO device information.
-    Hardware properties such as device model, MAC address, memory information,
-    and hardware and software information is contained here."""
+
+    Hardware properties such as device model, MAC address, memory information, and
+    hardware and software information is contained here.
+    """
 
     def __init__(self, data):
-        """
-        Response of a Xiaomi Smart WiFi Plug
+        """Response of a Xiaomi Smart WiFi Plug.
 
         {'ap': {'bssid': 'FF:FF:FF:FF:FF:FF', 'rssi': -68, 'ssid': 'network'},
          'cfg_time': 0,
@@ -99,12 +101,39 @@ class DeviceInfo:
         return self.data
 
 
+class DeviceStatus:
+    """Base class for status containers.
+
+    All status container classes should inherit from this class. The __repr__
+    implementation returns all defined properties and their values.
+    """
+
+    def __repr__(self):
+        props = inspect.getmembers(self.__class__, lambda o: isinstance(o, property))
+
+        s = f"<{self.__class__.__name__}"
+        for prop_tuple in props:
+            name, prop = prop_tuple
+            try:
+                prop_value = prop.fget(self)
+            except Exception as ex:
+                prop_value = ex.__class__.__name__
+
+            s += f" {name}={prop_value}"
+        s += ">"
+        return s
+
+
 class Device(metaclass=DeviceGroupMeta):
     """Base class for all device implementations.
-    This is the main class providing the basic protocol handling for devices using
-    the ``miIO`` protocol.
-    This class should not be initialized directly but a device-specific class inheriting
-    it should be used instead of it."""
+
+    This is the main class providing the basic protocol handling for devices using the
+    ``miIO`` protocol. This class should not be initialized directly but a device-
+    specific class inheriting it should be used instead of it.
+    """
+
+    retry_count = 3
+    timeout = 5
 
     def __init__(
         self,
@@ -113,18 +142,22 @@ class Device(metaclass=DeviceGroupMeta):
         start_id: int = 0,
         debug: int = 0,
         lazy_discover: bool = True,
+        timeout: int = None,
     ) -> None:
         self.ip = ip
         self.token = token
-        self._protocol = MiIOProtocol(ip, token, start_id, debug, lazy_discover)
+        timeout = timeout if timeout is not None else self.timeout
+        self._protocol = MiIOProtocol(
+            ip, token, start_id, debug, lazy_discover, timeout
+        )
 
     def send(
         self,
         command: str,
         parameters: Any = None,
-        retry_count=3,
+        retry_count: int = None,
         *,
-        extra_parameters=None
+        extra_parameters=None,
     ) -> Any:
         """Send a command to the device.
 
@@ -140,6 +173,7 @@ class Device(metaclass=DeviceGroupMeta):
         :param int retry_count: How many times to retry on error
         :param dict extra_parameters: Extra top-level parameters
         """
+        retry_count = retry_count if retry_count is not None else self.retry_count
         return self._protocol.send(
             command, parameters, retry_count, extra_parameters=extra_parameters
         )
@@ -153,12 +187,12 @@ class Device(metaclass=DeviceGroupMeta):
         click.argument("parameters", type=LiteralParamType(), required=False),
     )
     def raw_command(self, command, parameters):
-        """Send a raw command to the device.
-        This is mostly useful when trying out commands which are not
-        implemented by a given device instance.
+        """Send a raw command to the device. This is mostly useful when trying out
+        commands which are not implemented by a given device instance.
 
         :param str command: Command to send
-        :param dict parameters: Parameters to send"""
+        :param dict parameters: Parameters to send
+        """
         return self.send(command, parameters)
 
     @command(
@@ -171,8 +205,10 @@ class Device(metaclass=DeviceGroupMeta):
     )
     def info(self) -> DeviceInfo:
         """Get miIO protocol information from the device.
-        This includes information about connected wlan network,
-        and hardware and software versions."""
+
+        This includes information about connected wlan network, and hardware and
+        software versions.
+        """
         try:
             return DeviceInfo(self.send("miIO.info"))
         except PayloadDecodeException as ex:
@@ -246,3 +282,6 @@ class Device(metaclass=DeviceGroupMeta):
             )
 
         return values
+
+    def __repr__(self):
+        return f"<{self.__class__.__name__ }: {self.ip} (token: {self.token})>"
